@@ -186,7 +186,7 @@ def get_json(defs):
             continue
         typehint_text = str(def_).replace("?", "")
         line = def_.line
-        end_line = def_.end_line
+        end_line = def_.end_line or line
         column = def_.column + 1
         end_column = column + len(typehint_text)
         description = describe(def_)
